@@ -2,10 +2,6 @@
 This module defines all of the Mixins that provide components of XBlock-family
 functionality, such as ScopeStorage, RuntimeServices, and Handlers.
 """
-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-
 from collections import OrderedDict
 import copy
 import functools
@@ -464,7 +460,7 @@ class XmlSerializationMixin(ScopedStorageMixin):
                 block.runtime.add_node_as_child(block, child, id_generator)
 
         # Attributes become fields.
-        for name, value in node.items():  # lxml has no iteritems
+        for name, value in list(node.items()):  # lxml has no iteritems
             cls._set_field_if_present(block, name, value, {})
 
         # Text content becomes "content", if such a field exists.
@@ -487,7 +483,7 @@ class XmlSerializationMixin(ScopedStorageMixin):
         node.set('xblock-family', self.entry_point)
 
         # Set node attributes based on our fields.
-        for field_name, field in self.fields.items():
+        for field_name, field in list(self.fields.items()):
             if field_name in ('children', 'parent', 'content'):
                 continue
             if field.is_set_on(self) or field.force_export:
@@ -560,9 +556,31 @@ class IndexInfoMixin:
         """
         return key/value fields to feed an index within in a Python dict object
         values may be numeric / string or dict
-        default implementation is an empty dict
         """
-        return {}
+        display_name = getattr(self, "display_name", None)
+
+        # Getting self.display_name.default wouldn't work as self.display_name is actually
+        # a str after the class instance is created. So, we can only access the default value
+        # of display_name field by accessing class variable of same name
+        content_type = getattr(
+            getattr(self.__class__, "display_name", None), "default", None
+        )
+
+        _index_dictionary = dict()
+
+        if display_name is not None:
+            _index_dictionary.update({
+                "content": {
+                    "display_name": display_name
+                }
+            })
+
+        if content_type is not None:
+            _index_dictionary.update({
+                "content_type": content_type
+            })
+
+        return _index_dictionary
 
 
 class ViewsMixin:
